@@ -28,8 +28,8 @@ function vacation_option_link_do()
 
    $optpage_blocks[] = array(
       'name' => _("Vacation Message"),
-      'url' => '../plugins/vacation_local/vac_init.php',
-      'desc' => _("Set up an auto-reply message for your incoming email.  This can be useful when you are away on vacation."),
+      'url' => SM_PATH . 'plugins/vacation_local/vac_init.php',
+      'desc' => _("Set up an auto-reply message and optionally forward your incoming email. This can be useful when you are away on vacation."),
       'js' => FALSE
    );
 
@@ -39,4 +39,4 @@ function vacation_option_link_do()
 }
 
 
-?>
+?>
\ No newline at end of file
